/* eslint-disable react/jsx-props-no-spreading */
import React, { FC, useState } from 'react';
import TextField from '@material-ui/core/TextField';
import Autocomplete from '@material-ui/lab/Autocomplete';
import { getSeniorList } from 'api/getSeniorList';
import { ResponseProps } from 'api/ResponseProps';

export const SeniorSearch: FC = () => {
  const [value, setValue] = useState<ResponseProps | null>(null);
  const [seniors, setSeniors] = useState<ResponseProps[]>([]);

  const handleChange = (newValue: string): void => {
    if (newValue !== undefined) {
      const MIN_SEARCH_LENGTH = 3;
      if (newValue.length >= MIN_SEARCH_LENGTH)
        getSeniorList(newValue).then((list) => {
          setSeniors(list);
        });
    }
  };

  return (
    <Autocomplete
      value={value}
      id="senior-searcher"
      onInputChange={(event, newValue) => handleChange(newValue)}
      onChange={(event, newValue) => {
        setValue(newValue);
      }}
      options={seniors}
      getOptionSelected={(option, val) => option.id === val.id}
      getOptionLabel={(option) => {
        if (Object.prototype.hasOwnProperty.call({ user: true }, 'user')) {
          return option.user.lastName;
        }
        return '';
      }}
      renderOption={(option) => (
        <>
          {option.user.firstName} {option.user.lastName} {option.user.username}
        </>
      )}
      renderInput={(params) => (
        <TextField
          {...params}
          label="Search a senior"
          variant="outlined"
          InputProps={{
            ...params.InputProps,
          }}
        />
      )}
    />
  );
};
